List available preprocessing functions Returns the preprocessing utilities provided by metabom8.
Source:R/utils_provenance.R
print_preprocessing.RdList available preprocessing functions Returns the preprocessing utilities provided by metabom8.
See also
Other preprocessing:
align_segment(),
align_spectra(),
binning(),
calibrate(),
correct_baseline(),
correct_lw(),
pqn()
Examples
list_preprocessing()
#> calibrate
#> "Chemical shift calibration to reference signal"
#> excise
#> "Remove spectral regions (e.g., residual water, urea)"
#> baseline_correct
#> "Baseline correction"
#> norm_erectic
#> "Normalise spectra based on ERETIC signal"
#> pqn
#> "Apply Probabilistic Quantile Normalisation (PQN)"
#> binning
#> "Bin spectra"
#> correct_lw
#> "Apply line width correction (experimental)"
#> align_segment
#> "Spectral alignment of a single chemical shift segment"
#> align_spectra
#> "Automated segment-wise full spectrum alignment"