Computes the Hotelling T^2 statistic defining a multivariate confidence region for a set of observations. The region corresponds to an ellipsoid in p-dimensional space and is commonly visualised as an ellipse in two-dimensional (OPLS) score plots.
Value
A named list with elements:
- center
Numeric vector of column means.
- cov
Sample covariance matrix.
- c2
Squared radius of the Hotelling T^2 region.